Documentation
¶
Overview ¶
Package foaf wrapper for FOAF.
Specification https://web.archive.org/web/20140909053226/http://api.yandex.ru/blogs/doc/indexation/concepts/what-is-foaf.xml
Index ¶
Constants ¶
const ( HTTPClient = internal.HTTPClientKey UserAgent = internal.UserAgentKey )
Context keys to use with https://golang.org/pkg/context WithValue function to associate.
const BaseURL = "https://vk.com/foaf.php"
BaseURL url foaf.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Date ¶
type Date struct {
Date string `xml:"date,attr"`
}
Date may be used to express temporal information at any level of granularity.
Use time.Parse(time.RFC3339, v.Date).
type Edu ¶
type Edu struct {
School School `xml:"school"`
University University `xml:"university"`
}
Edu struct.
type ErrorStatusCode ¶ added in v2.15.0
type ErrorStatusCode struct {
Code int
}
ErrorStatusCode struct.
func (ErrorStatusCode) Error ¶ added in v2.15.0
func (e ErrorStatusCode) Error() string
type Gender ¶
type Gender string
Gender - the gender of this Agent (typically but not necessarily 'male' or 'female').
type Group ¶
type Group struct {
GroupType GroupType `xml:"groupType"`
Name string `xml:"name"`
URI []URI `xml:"URI"`
Img Img `xml:"img"`
Weblog Weblog `xml:"weblog"`
MembersCount int `xml:"membersCount"`
StartDate Date `xml:"startDate"`
FinishDate Date `xml:"finishDate"`
}
Group - A class of Agents.
type Image ¶
type Image struct {
Primary string `xml:"primary,attr"`
Width int `xml:"width,attr"`
Height int `xml:"height,attr"`
About string `xml:"about,attr"`
Thumbnail []Thumbnail `xml:"thumbnail"`
}
Image digital images (such as JPEG, PNG, GIF bitmaps, SVG diagrams etc.).
type Img ¶
type Img struct {
Image Image `xml:"Image"`
}
Img - An image that can be used to represent some thing (ie. those depictions which are particularly representative of something, eg. one's photo on a homepage).
type Military ¶
type Military struct {
Title string `xml:"title,attr"`
DateStart string `xml:"dateStart,attr"`
About string `xml:"about,attr"`
Location Location `xml:"location"`
}
Military struct.
type Person ¶
type Person struct {
PublicAccess Access `xml:"publicAccess"`
ProfileState ProfileState `xml:"profileState"`
URI []URI `xml:"URI"`
FirstName string `xml:"firstName"`
SecondName string `xml:"secondName"`
Name string `xml:"name"`
Weblog Weblog `xml:"weblog"`
Gender Gender `xml:"gender"`
Created Date `xml:"created"`
LastLoggedIn Date `xml:"lastLoggedIn"`
Modified Date `xml:"modified"`
SubscribersCount int `xml:"subscribersCount"`
FriendsCount int `xml:"friendsCount"`
SubscribedToCount int `xml:"subscribedToCount"`
Birthday string `xml:"birthday"`
DateOfBirth string `xml:"dateOfBirth"`
Img Img `xml:"img"`
FamilyStatus string `xml:"familyStatus"`
SkypeID string `xml:"skypeID"` // A Skype ID
Homepage string `xml:"homepage"`
Phone []Phone `xml:"phone"`
ExternalProfile []External `xml:"externalProfile"`
Interest string `xml:"interest"`
LocationOfBirth Location `xml:"locationOfBirth"`
Location Location `xml:"location"`
Edu []Edu `xml:"edu"`
Job []Job `xml:"job"`
}
Person - A person.
type ProfileState ¶
type ProfileState string
ProfileState is profile state.
const ( ProfileStateDeleted ProfileState = "deleted" ProfileStateVerified ProfileState = "verified" ProfileStateActive ProfileState = "active" ProfileStateBanned ProfileState = "banned" ProfileStateDeactivated ProfileState = "deactivated" )
Types of ProfileState.
type School ¶
type School struct {
Title string `xml:"title,attr"`
DateStart string `xml:"dateStart,attr"`
DateFinish string `xml:"dateFinish,attr"`
About string `xml:"about,attr"`
Location Location `xml:"location"`
}
School struct.
type Thumbnail ¶
type Thumbnail struct {
Width int `xml:"width,attr"`
Height int `xml:"height,attr"`
Resource string `xml:"resource,attr"`
}
Thumbnail a derived thumbnail image.
type University ¶
type University struct {
Title string `xml:"title,attr"`
ShortCaption string `xml:"shortCaption,attr"`
DateFinish string `xml:"dateFinish,attr"`
About string `xml:"about,attr"`
Location Location `xml:"location"`
}
University struct.